@@ -17,7 +17,7 @@ from .view import Request, Response
 if t.TYPE_CHECKING:
     from .module import Module
 
-session_handler: Request  # session处理类
+session_handler: Request   # session处理类
 
 
 class Mx(BaseMx):
@@ -29,7 +29,6 @@ class Mx(BaseMx):
         super().__init__(**options)
         self.after_request_funcs = dict()
         self.before_request_funcs = dict()
-        self._ = None
 
     def before_request(self, f):
         self.before_request_funcs.setdefault(None, []).append(f)
@@ -54,7 +53,8 @@ class Mx(BaseMx):
             raise CError('session.GetHttpResponseHead().SetContentType()')
         return request
 
-    def package_data(self, data: t.Any, callback: str) -> json:
+    @staticmethod
+    def package_data(data: t.Any, callback: str) -> json:
         """
         打包响应数据
         :param data: 视图返回的数据
@@ -62,15 +62,10 @@ class Mx(BaseMx):
         :return: 打包后的数据
         """
         if isinstance(data, tuple):
-            data = json.dumps(
-                {'status': 'success', 'errmsg': self._(data[0]), 'data': data[1] if len(data) == 2 else data[1:]},
-                ensure_ascii=False) if self._ else json.dumps(
-                {'status': 'success', 'errmsg': data[0], 'data': data[1] if len(data) == 2 else data[1:]},
-                ensure_ascii=False)
+            data = json.dumps({'status': 'success', 'errmsg': data[0], 'data': data[1] if len(data) == 2 else data[1:]},
+                              ensure_ascii=False)
         else:
-            data = json.dumps({'status': 'failed', 'errmsg': self._(data)},
-                              ensure_ascii=False) if self._ else json.dumps({'status': 'failed', 'errmsg': data},
-                                                                            ensure_ascii=False)
+            data = json.dumps({'status': 'failed', 'errmsg': data}, ensure_ascii=False)
 
         if callback:
             data = '%s(%s)' % (callback, data)
@@ -107,7 +102,7 @@ class Mx(BaseMx):
 
         global session_handler
         session_handler = self.session_handler
-
+        
         url = self.session_handler.url
         if url is None:
             url = ''
